@@ -16,13 +16,13 @@ var logger = require('winston');
 var fscan = require('./../common/fscan');
 const work_dir = process.cwd();
 const config = require(process.cwd() + '/config/config');
-var db = require('rethinkdbdash')(config.database);
-
+var db = require('rethinkdbdash')(Object.assign({},config.database,{user:config.appId,password:config.appKey}));
+var cookieParser = require('cookie-parser');
 
 module.exports = function (nylon_path) {
     logger.info("nylon Server run at env : " + process.env.NODE_ENV);
     var app = express();
-
+    app.use(cookieParser());
     /** load express module */
 
     console.log("work_dir::" + work_dir);
@@ -37,6 +37,8 @@ module.exports = function (nylon_path) {
             } catch (err) {
                 logger.error(err);
                 next();
+
+                
             }
         }, function (err) {
 
