@@ -33,7 +33,7 @@ module.exports = function (app, db) {
         saveUninitialized: true,
         key: 'sid',
         secret: 'my5uperSEC537(key)!',
-        cookie: { maxAge: 5 * 60 * 1000 },
+      //  cookie: { maxAge: 5 * 60 * 1000 },
         store: rdbStore
     }));
 
@@ -44,8 +44,6 @@ module.exports = function (app, db) {
         req.logger = logger;
         res.header("Access-Control-Allow-Origin", "*");
         res.header("Access-Control-Allow-Headers", "Origin, X-Custom-Header, X-Requested-With, Content-Type, Accept, X-APP-ID, X-APP-KEY, Authorization");
-        // Access-Control-Allow-Headers
-
         next();
     });
 
