@@ -10,7 +10,9 @@
 */
 var passport = require('passport');
 var URL = require('url');
-module.exports = function ( app, db) {
+const config = require(process.cwd() + '/config/config');
+
+module.exports = function (app, db) {
 
     app.use(passport.initialize());
     app.use(passport.session());
@@ -23,11 +25,15 @@ module.exports = function ( app, db) {
         }
     );
 
+    var callbackLogin = function (user, done) {
+       
+    }
+
     passport.deserializeUser(
         function (id, done) {
             try {
                 console.log('deserializeUser');
-               console.log(id);
+                console.log(id);
                 var user = {};
                 db.db('oauth')
                     .table('users')
@@ -50,21 +56,22 @@ module.exports = function ( app, db) {
                         }
 
                     }).catch(function (err) {
-                        return done(null,false);
+                        return done(null, false);
                     });
-            }catch(err){
-                 return done(null,false);
+            } catch (err) {
+                return done(null, false);
             }
 
-           
+
         }
     );
 
 
-    require('./../oauth/oauth.local')(db);
-    require('./../oauth/oauth.facebook')(db);
-    require('./../oauth/oauth.google')(db);
+  //  if (config.appId == "d8fcffc5-d1ab-40f1-ac63-d2643d7b9464") {
+        require('./../oauth/oauth.local')(db);
+        require('./../oauth/oauth.facebook')(db);
+        require('./../oauth/oauth.google')(db);
+ //   }
     require('./../oauth/oauth.jwt')(db);
-    
 
 }
\ No newline at end of file
