@@ -12,7 +12,7 @@
 var sass=require('node-sass-middleware');
 const work_dir=process.cwd();
 
-module.exports=function(callback,app){
+module.exports=function(app){
      app.use(sass({
         src:work_dir+'/sass',
         dest:work_dir+'/public/css',
@@ -20,6 +20,6 @@ module.exports=function(callback,app){
         prefix:'/css'
     }));
 
-    callback();
+    
 
 }
\ No newline at end of file
