@@ -12,14 +12,14 @@
 var java = require('java');
 var logger = require('winston');
 var async = require('async');
-var fscan = require('./../common/fscan');
 const config = require(process.cwd() + '/config/config');
 
 var jdbc;
-module.exports = function (callback,app) {
-
-    app.use(function (req, res, next) {
-        try {
+module.exports = function (app) {
+    
+    var jdbc_function = {
+        query: function (driver, sql, parameters, callback) {
+            
             if (jdbc == undefined) {
                 console.log("jdbc first time");
                 var JDBCConnect = java.import("nylon.data.JDBCConnect");
@@ -34,22 +34,28 @@ module.exports = function (callback,app) {
                             }
                         );
                     } catch (error) {
-                        next(error);
+                        next();
                     }
                 }, function (err) {
-                    //callback(err, jdbc);
+                    jdbc.query(driver, sql, parameters, function (err, data) {
+                        callback(err, data);
+                    });
+                });
+            } else {
+                jdbc.query(driver, sql, parameters, function (err, data) {
+                    callback(err, data);
                 });
             }
-
-            req.jdbc = jdbc;
-            next();
-
-        } catch (error) {
-            console.log(error);
-            next();
         }
+    }
+
+    app.use(function (req, res, next) {
+
+        req.jdbc = jdbc_function;
+        next();
+
     });
 
-    callback();
+    // callback();
 
 }
\ No newline at end of file
